@@ -5,7 +5,7 @@ import os
 from pathlib import Path
 
 # Module imports
-from flatcode.core.ignore import bootstrap_mergeignore, load_ignore_rules
+from flatcode.core.ignore import bootstrap_mergeignore, load_ignore_spec
 from flatcode.core.scanner import ProjectScanner
 from flatcode.core.tree import generate_project_tree
 from flatcode.models import FileContext
@@ -15,11 +15,33 @@ def create_arg_parser():
         description="A smart CLI tool to 'flatten' your project's code into a single, LLM-friendly context file."
     )
     parser.add_argument("root_dir", type=str, nargs="?", default=os.getcwd(), help="Project root directory")
-    parser.add_argument("-o", "--output", type=str, default="merged_code_context.txt", help="Output filename")
+    
+    # [Modify] 默认值改为 None，以便在 main 中动态生成
+    parser.add_argument(
+        "-o", "--output", 
+        type=str, 
+        default=None, 
+        help="Output filename (default: {folder_name}_context.txt)"
+    )
+    
     parser.add_argument("-e", "--extensions", type=str, default="*", help="Comma-separated file extensions or '*' for all")
     parser.add_argument("-y", "--yes", action="store_true", help="Skip confirmation")
     return parser
 
+def get_default_output_name(root_dir: Path) -> str:
+    """Generates a dynamic filename based on the directory name."""
+    # 获取目录名称 (如 'backend')
+    folder_name = root_dir.name
+    
+    # 边界情况：如果是根目录或无法获取名称
+    if not folder_name:
+        folder_name = "project"
+        
+    # 简单的清理（可选）：将空格替换为下划线，防止文件名带空格
+    safe_name = folder_name.replace(" ", "_")
+    
+    return f"{safe_name}_context.txt"
+
 def main():
     try:
         # 1. Setup
@@ -31,7 +53,13 @@ def main():
             print(f"Error: Invalid directory '{root_dir}'", file=sys.stderr)
             sys.exit(1)
 
-        output_file = root_dir / args.output
+        # [Modify] 动态计算输出文件名
+        if args.output:
+            output_file_name = args.output
+        else:
+            output_file_name = get_default_output_name(root_dir)
+            
+        output_file = root_dir / output_file_name
         
         # Parse extensions
         raw_exts = args.extensions.strip()
@@ -39,16 +67,18 @@ def main():
 
         print(f"--- flatcode ---")
         print(f"Scanning: {root_dir}")
-        print(f"Mode: {'All non-ignored text files' if '*' in extensions else f'Extensions {extensions}'}")
+        print(f"Output:   {output_file.name}") # 提示用户输出文件名
+        print(f"Mode:     {'All non-ignored text files' if '*' in extensions else f'Extensions {extensions}'}")
 
-        # 2. Ignore Rules
-        mergeignore_file = bootstrap_mergeignore(root_dir, args.output)
-        ignore_rules = load_ignore_rules(mergeignore_file)
-        ignore_rules.append((args.output, False)) # Always ignore output file
+        # 2. Ignore Rules (Using PathSpec)
+        # 传入 output_file_name 而不是 args.output，确保动态生成的文件名被添加到 ignore
+        mergeignore_file = bootstrap_mergeignore(root_dir, output_file_name)
+        
+        # Load spec and inject the output filename as an extra pattern to ignore
+        ignore_spec = load_ignore_spec(mergeignore_file, extra_patterns=[output_file_name])
 
         # 3. Scanning
-        scanner = ProjectScanner(root_dir, ignore_rules, extensions)
-        # Consume the generator into a list for sorting/stats
+        scanner = ProjectScanner(root_dir, ignore_spec, extensions)
         files_to_merge: list[FileContext] = list(scanner.scan())
         
         if not files_to_merge:
@@ -70,8 +100,7 @@ def main():
         print("-" * 60)
 
         if not args.yes:
-            # Simple confirmation logic
-            pass # Skipping implemented logic for brevity, assumed implicitly approved or -y used
+            pass 
 
         # 5. Output Generation
         tree_str = generate_project_tree([f.rel_path for f in files_to_merge], root_dir.name)
@@ -97,5 +126,9 @@ def main():
         print("\nCancelled.")
         sys.exit(1)
 
+    except Exception as e:
+        print(f"An unexpected error occurred: {e}", file=sys.stderr)
+        sys.exit(1)
+
 if __name__ == "__main__":
-    main()
+    main()
\ No newline at end of file
